==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/networkfirewall/kotlin/inputs/FirewallPolicyFirewallPolicyPolicyVariablesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.networkfirewall.kotlin.inputs

import com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyPolicyVariablesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property ruleVariables
 */
public data class FirewallPolicyFirewallPolicyPolicyVariablesArgs(
    public val ruleVariables:
    Output<List<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyPolicyVariablesArgs> {
    override fun toJava():
        com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyPolicyVariablesArgs =
        com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyPolicyVariablesArgs.builder()
            .ruleVariables(
                ruleVariables?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [FirewallPolicyFirewallPolicyPolicyVariablesArgs].
 */
@PulumiTagMarker
public class FirewallPolicyFirewallPolicyPolicyVariablesArgsBuilder internal constructor() {
    private var ruleVariables:
        Output<List<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>>? = null

    /**
     * @param value
     */
    @JvmName("hqcnvujapbjchvcw")
    public suspend
    fun ruleVariables(`value`: Output<List<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>>) {
        this.ruleVariables = value
    }

    @JvmName("dqouhbtpjtijottw")
    public suspend fun ruleVariables(
        vararg
        values: Output<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>,
    ) {
        this.ruleVariables = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("fehjweeeenhuqdqi")
    public suspend
    fun ruleVariables(values: List<Output<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>>) {
        this.ruleVariables = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("anjjctykalyejfiy")
    public suspend
    fun ruleVariables(`value`: List<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ruleVariables = mapped
    }

    /**
     * @param argument
     */
    @JvmName("pqicfvofkgvydloo")
    public suspend
    fun ruleVariables(argument: List<suspend FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ruleVariables = mapped
    }

    /**
     * @param argument
     */
    @JvmName("hdlkuimnsrgktrau")
    public suspend fun ruleVariables(
        vararg
        argument: suspend FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ruleVariables = mapped
    }

    /**
     * @param argument
     */
    @JvmName("rlflainresoseleq")
    public suspend
    fun ruleVariables(argument: suspend FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.ruleVariables = mapped
    }

    /**
     * @param values
     */
    @JvmName("bxefrxsakmwnljte")
    public suspend fun ruleVariables(
        vararg
        values: FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleVariables = mapped
    }

    internal fun build(): FirewallPolicyFirewallPolicyPolicyVariablesArgs =
        FirewallPolicyFirewallPolicyPolicyVariablesArgs(
            ruleVariables = ruleVariables,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/networkfirewall/kotlin/inputs/FirewallPolicyFirewallPolicyPolicyVariablesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.networkfirewall.kotlin.inputs

import com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyPolicyVariablesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property ruleVariables
 */
public data class FirewallPolicyFirewallPolicyPolicyVariablesArgs(
    public val ruleVariables: Output<List<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyPolicyVariablesArgs> {
    override fun toJava(): com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyPolicyVariablesArgs =
        com.pulumi.aws.networkfirewall.inputs.FirewallPolicyFirewallPolicyPolicyVariablesArgs.builder()
            .ruleVariables(
                ruleVariables?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [FirewallPolicyFirewallPolicyPolicyVariablesArgs].
 */
@PulumiTagMarker
public class FirewallPolicyFirewallPolicyPolicyVariablesArgsBuilder internal constructor() {
    private var ruleVariables:
        Output<List<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>>? = null

    /**
     * @param value
     */
    @JvmName("qtlxigqabxmdqtdm")
    public suspend fun ruleVariables(`value`: Output<List<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>>) {
        this.ruleVariables = value
    }

    @JvmName("pyicybvdnrgsibea")
    public suspend fun ruleVariables(vararg values: Output<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>) {
        this.ruleVariables = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("iyrsqjdeguaockia")
    public suspend fun ruleVariables(values: List<Output<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>>) {
        this.ruleVariables = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("tklhugjqnearojym")
    public suspend fun ruleVariables(`value`: List<FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ruleVariables = mapped
    }

    /**
     * @param argument
     */
    @JvmName("smyvplcyjnuocmhm")
    public suspend fun ruleVariables(argument: List<suspend FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ruleVariables = mapped
    }

    /**
     * @param argument
     */
    @JvmName("usylxjidllfgeafl")
    public suspend fun ruleVariables(vararg argument: suspend FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.ruleVariables = mapped
    }

    /**
     * @param argument
     */
    @JvmName("tcwkvumxmrjvdtcr")
    public suspend fun ruleVariables(argument: suspend FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.ruleVariables = mapped
    }

    /**
     * @param values
     */
    @JvmName("ukaqhkiymxdbqhck")
    public suspend fun ruleVariables(vararg values: FirewallPolicyFirewallPolicyPolicyVariablesRuleVariableArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleVariables = mapped
    }

    internal fun build(): FirewallPolicyFirewallPolicyPolicyVariablesArgs =
        FirewallPolicyFirewallPolicyPolicyVariablesArgs(
            ruleVariables = ruleVariables,
        )
}
